@@ -10,12 +10,12 @@ def choose_database_type(project_type):
     print("Setting your project")
     print("Choose an database option")
 
-    posible_dbs=databases.copy()
+    possible_dbs=databases.copy()
 
     if project_type=="docker":
-        del posible_dbs["3"]
+        del possible_dbs["3"]
 
-    for key, vale in posible_dbs.items():
+    for key, vale in possible_dbs.items():
         print(f"[{key}] >> Use {vale}")
 
     db_option = prompt("Your option is? ")
