@@ -1,5 +1,5 @@
-from typer import Typer
 import os
+from typer import Typer
 from kamaqi.utils.files import read_project_file
 
 app = Typer(help="Run your project")
@@ -12,7 +12,13 @@ def run_project():
     project_name = project_file["project_name"]
 
     if project_file["project_type"] == "normal":
-        os.system("source env/bin/activate")
+        
+        if os.name=="posix":
+            os.system("source env/bin/activate")
+
+        if os.name=="nt":
+            os.system(f".\env\Scripts\\activate")
+
         os.system("uvicorn main:app --reload")
 
     if  project_file["project_type"] == "docker":
